==> udkanbun-1.2.7-py3-none-any.whl: udkanbun/cli.py <==
import sys
from udkanbun import UDKanbun

def main():
  argc=len(sys.argv)
  i=w=1
  optu=optt=optk=False
  while i<argc:
    o=sys.argv[i]
    if o=="-h" or o=="--help" or o=="-v" or o=="--version":
      usage()
    elif o=="-u":
      optu=True
    elif o=="-t" or o=="-t1":
      optt=True
      w=1
    elif o=="-t2":
      optt=True
      w=2
    elif o=="-k":
      optk=True
    else:
      break
    i+=1
  else:
    lzh=UDKanbun(True)
    while True:
      try:
        s=input()
      except:
        return
      print(output(lzh,optu,optt,optk,w,s),end="")
  lzh=UDKanbun(True)
  while i<argc:
    f=open(sys.argv[i],"r",encoding="utf-8")
    s=f.read()
    f.close()
    print(output(lzh,optu,optt,optk,w,s),end="")
    i+=1

def output(lzh,optu,optt,optk,width,sentence):
  if optt==True:
    return lzh(sentence).to_tree(BoxDrawingWidth=width,kaeriten=optk)
  if optu==True:
    if optk==False:
      return(lzh(sentence,raw=True))
    t=lzh(sentence)
    k=t.kaeriten().split("\n")
    s=""
    for i,r in enumerate(str(t).split("\n\n")):
      if r=="":
        continue
      for u in r.split("\n"):
        if u=="":
          continue
        s+=u+"\n"
        if u.startswith("# text = "):
          s+="# text_with_kaeriten = "+k[i]+"\n"
      s+="\n"
    return s
  if optk==True:
    return(lzh(sentence).kaeriten())
  return(lzh(sentence,raw=True))

def usage():
  from pkg_resources import get_distribution
  print("UD-Kanbun Version "+get_distribution("udkanbun").version,file=sys.stderr)
  print("Usage: udkanbun [-u|-t|-t2|-k] file",file=sys.stderr)
  print("  output format:",file=sys.stderr)
  print("    -u  Universal Dependencies CoNLL-U",file=sys.stderr)
  print("    -t  tree (optional BoxDrawingWidth)",file=sys.stderr)
  print("    -k  kaeriten",file=sys.stderr)
  sys.exit()

if __name__=="__main__":
  main()

==> udkanbun-1.3.5-py3-none-any.whl: udkanbun/cli.py <==
import sys
from udkanbun import UDKanbun

def main():
  argc=len(sys.argv)
  i=w=1
  optu=optt=optk=False
  while i<argc:
    o=sys.argv[i]
    if o=="-h" or o=="--help" or o=="-v" or o=="--version":
      usage()
    elif o=="-u":
      optu=True
    elif o=="-t" or o=="-t1":
      optt=True
      w=1
    elif o=="-t2":
      optt=True
      w=2
    elif o=="-k":
      optk=True
    else:
      break
    i+=1
  else:
    lzh=UDKanbun(True)
    while True:
      try:
        s=input()
      except:
        return
      print(output(lzh,optu,optt,optk,w,s),end="")
  lzh=UDKanbun(True)
  while i<argc:
    f=open(sys.argv[i],"r",encoding="utf-8")
    s=f.read()
    f.close()
    print(output(lzh,optu,optt,optk,w,s),end="")
    i+=1

def output(lzh,optu,optt,optk,width,sentence):
  if optt==True:
    return lzh(sentence).to_tree(BoxDrawingWidth=width,kaeriten=optk,Japanese=optk)
  if optu==True:
    if optk==False:
      return lzh(sentence,raw=True)
    t=lzh(sentence)
    k=t.kaeriten().split("\n")
    s=""
    for i,r in enumerate(str(t).split("\n\n")):
      if r=="":
        continue
      for u in r.split("\n"):
        if u=="":
          continue
        s+=u+"\n"
        if u.startswith("# text = "):
          s+="# text_with_kaeriten = "+k[i]+"\n"
      s+="\n"
    return s
  if optk==True:
    return lzh(sentence).kaeriten()
  return lzh(sentence,raw=True)

def usage():
  from pkg_resources import get_distribution
  print("UD-Kanbun Version "+get_distribution("udkanbun").version,file=sys.stderr)
  print("Usage: udkanbun [-u|-t|-t2|-k] file",file=sys.stderr)
  print("  output format:",file=sys.stderr)
  print("    -u  Universal Dependencies CoNLL-U",file=sys.stderr)
  print("    -t  tree  (-t2  tree with BoxDrawingWidth=2)",file=sys.stderr)
  print("    -k  kaeriten",file=sys.stderr)
  sys.exit()

if __name__=="__main__":
  main()
